Crate bookbinder_latex

Crate bookbinder_latex 

This crate provides support, with various options, for transforming a BookSrc into a latex file or a pdf generated from that file.

Structs

OptionsWithRenderedPreamble
Options with a prerendered preamble; normally derived from PreambleOptions.
PreambleOptions
Options for generating a pdf through LaTeX

Enums

LatexSecNumDepth
The numbering depth to use for section headings
PaperSize
Possible paper sizes with preconfigured margins

Traits

PdfRenderer
Support for rendering to a pdf file
TexRenderer
Support for rendering to a tex document