This crate provides support, with various options, for transforming a BookSrc into a latex file or a pdf generated from that file.
Structs
- Options
With Rendered Preamble - Options with a prerendered preamble;
normally derived from
PreambleOptions. - Preamble
Options - Options for generating a pdf through LaTeX
Enums
- Latex
SecNum Depth - The numbering depth to use for section headings
- Paper
Size - Possible paper sizes with preconfigured margins
Traits
- PdfRenderer
- Support for rendering to a pdf file
- TexRenderer
- Support for rendering to a tex document